@@ -1,14 +1,16 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::OnlyCorePrereqs; # git description: v0.020-9-g6025967
+package Dist::Zilla::Plugin::OnlyCorePrereqs; # git description: v0.021-7-g216d8fa
 # ABSTRACT: Check that no prerequisites are declared that are not part of core
 # KEYWORDS: plugin distribution metadata prerequisites core
 # vim: set ts=8 sw=4 tw=78 et :
-our $VERSION = '0.021';
+
+our $VERSION = '0.022';
+
 use Moose;
 with 'Dist::Zilla::Role::AfterBuild';
 use Moose::Util::TypeConstraints;
-use Module::CoreList 3.10;
+use Module::CoreList 5.20150214;
 use MooseX::Types::Perl 0.101340 'LaxVersionStr';
 use version;
 use Encode;
@@ -114,7 +116,9 @@ around dump_config => sub
     $config->{+__PACKAGE__} = {
         ( map { $_ => [ $self->$_ ] } qw(phases skips also_disallow)),
         ( map { $_ => $self->$_ } qw(deprecated_ok check_dual_life_versions)),
-        ( starting_version => ($self->_has_starting_version ? $self->starting_version : 'to be determined from perl prereq')),
+        ( starting_version => ($self->_has_starting_version
+                ? $self->starting_version->numify
+                : 'to be determined from perl prereq')),
     };
 
     return $config;
@@ -166,13 +170,13 @@ sub after_build
 
             if ($self->check_dual_life_versions or not $self->_is_dual($prereq))
             {
-                my $has = $Module::CoreList::version{$self->starting_version->numify}{$prereq};
+                my $has = $Module::CoreList::version{$self->starting_version->stringify}{$prereq};
                 $has = version->parse($has);    # version.pm XS hates tie() - RT#87983
                 my $wanted = version->parse($prereqs->{$phase}{requires}{$prereq});
 
                 if ($has < $wanted)
                 {
-                    push @insufficient_version, [ map { "$_" } $phase, $prereq, $wanted, $self->starting_version, $has ];
+                    push @insufficient_version, [ map { "$_" } $phase, $prereq, $wanted, $self->starting_version->numify, $has ];
                     next;
                 }
             }
@@ -281,7 +285,7 @@ Dist::Zilla::Plugin::OnlyCorePrereqs - Check that no prerequisites are declared
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
